==> libreoffice-libs-core-3.3.2.2.tar.bz2: libreoffice-libs-core-3.3.2.2/sfx2/source/bastyp/sfxresid.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sfx2.hxx"

#include <tools/simplerm.hxx>

#include "sfxresid.hxx"
#include <sfx2/app.hxx>

// -----------------------------------------------------------------------

static ResMgr* pMgr=NULL;

SfxResId::SfxResId( USHORT nId ) :

    ResId( nId, *GetResMgr() )
{
}

//============================================================================
//
// SfxSimpleResId Implementation.
//
//============================================================================

SfxSimpleResId::SfxSimpleResId(USHORT nID):
    m_sText( SFX_APP()->GetSimpleResManager()->ReadString(nID) )
{}

ResMgr* SfxResId::GetResMgr()
{
    if ( !pMgr )
    {
        pMgr = SfxApplication::CreateResManager("sfx");
    }

    return pMgr;
}

void SfxResId::DeleteResMgr()
{
    DELETEZ( pMgr );
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-libs-core-3.4.4.2.tar.bz2: libreoffice-libs-core-3.4.4.2/sfx2/source/bastyp/sfxresid.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sfx2.hxx"

#include <tools/simplerm.hxx>

#include "sfx2/sfxresid.hxx"
#include <sfx2/app.hxx>

// -----------------------------------------------------------------------

static ResMgr* pMgr=NULL;

SfxResId::SfxResId( sal_uInt16 nId ) :

    ResId( nId, *GetResMgr() )
{
}

//============================================================================
// SfxSimpleResId Implementation.
//============================================================================

SfxSimpleResId::SfxSimpleResId(sal_uInt16 nID):
    m_sText( SFX_APP()->GetSimpleResManager()->ReadString(nID) )
{}

ResMgr* SfxResId::GetResMgr()
{
    if ( !pMgr )
    {
        pMgr = SfxApplication::CreateResManager("sfx");
    }

    return pMgr;
}

void SfxResId::DeleteResMgr()
{
    DELETEZ( pMgr );
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
